// Comm.cpp: implementation of the CComm class.
// Author : Philip Allen
// Version :1.1
// Date   : 16 March 2006
//
//////////////////////////////////////////////////////////////////////

#include "StdAfx.h"
#include "Comm.h"

#ifdef _DEBUG
#undef THIS_FILE
static char THIS_FILE[]=__FILE__;
#define new DEBUG_NEW
#endif

//////////////////////////////////////////////////////////////////////
// Construction/Destruction
//////////////////////////////////////////////////////////////////////

CComm::CComm()
{
	// Default states
	    mComPort = "Com1";
		mBaudRate = 9600;
		mByteSize = 8;
		mParity = NOPARITY;
		mStopBits = ONESTOPBIT;
		mAbortOnError = TRUE;
}


// Destructor clears handle for port
CComm::~CComm()
{
	if(GetCommState(m_hCom, &m_dcb))
	{
		CloseHandle(m_hCom);
	}
}



BOOL CComm::ClosePort()
{
	CloseHandle(m_hCom);
	return m_bPortReady;
}


BOOL CComm::OpenPort(CString sPort)
{

	mComPort = sPort;

	m_hCom = CreateFile(sPort, 
		GENERIC_READ | GENERIC_WRITE,
		0, // exclusive access
		NULL, // no security
		OPEN_EXISTING,
		0, // no overlapped I/O
		NULL); // null template 

	m_bPortReady = SetupComm(m_hCom, 128, 128); // set buffer sizes

	if (m_bPortReady)
	{
		m_bPortReady = GetCommState(m_hCom, &m_dcb);		
		m_dcb.BaudRate = mBaudRate;
		m_dcb.ByteSize = mByteSize;
		m_dcb.Parity = mParity;
		m_dcb.StopBits = mStopBits;
		m_dcb.fAbortOnError = mAbortOnError;
	}

	m_bPortReady = SetCommState(m_hCom, &m_dcb);

	return m_bPortReady;
}


BOOL CComm::Output(CString sOutString)
{
	// The function below only allows 1 byte to be transmitted
	//  so the NULL (0) value can be used as data
	bWriteRC = WriteFile(m_hCom, sOutString, 1, &iBytesWritten, NULL);

	return TRUE;

}

void CComm::SendCommand(CString cmd, unsigned short Data)
{
    Output(cmd);
    Output((char)Data);
    Sleep( 10);

    
}


int CComm::SetPort(const CString port)
{
	// Set local member for global checking
	mComPort = port;

	// First check if port is open and close if it is
	if(GetCommState(m_hCom, &m_dcb))
	{
		ClosePort();
	}

   	return OpenPort(port);

}
	
